<?php
/**
 * @author e-Commerce Dev Team
 * @file coupon.inc
 * Let store managers to create coupons and discount tickets
 */

/**
 * List Coupons
 */
function _coupon_admin_list($created, $method) {
  $head = $rows = array();

  if ($method == 'csv') {
    header('Content-Type: ', 'application/x-csv');
    header('Content-Disposition: attachment; filename="coupons.csv"' );
  }
  else {
    $head = array(
      array('data' => t('Coupon'), 'field' => 'coupon'),
      array('data' => t('Type of Discount')),
      array('data' => t('Discount Paid'), 'field' => 'coupon_discount'),
      array('data' => t('Discount Available')),
      array('data' => t('Created'), 'field' => 'created', 'sort' => 'asc'),
      array('data' => t('Transaction'), 'field' => 'created_txnid'),
      array(),
    );
  }
  $sql = 'FROM {ec_coupon} c
    LEFT JOIN {ec_transaction_coupon} tc ON c.coupon = tc.coupon';
  if (!empty($created) and is_numeric($created)) {
    $sql .= " WHERE created = $created";
  }
  $sql_count = 'SELECT COUNT(c.coupon) '. $sql;
  $sql = 'SELECT c.*, SUM(tc.discount) as coupon_discount '. $sql .
    ' GROUP BY c.coupon, c.operator, c.operand, c.created,
    c.created_txnid, c.created_vid';
  if (!empty($method)) {
    $result = db_query($sql);
  }
  else {
    $result = pager_query($sql . tablesort_sql($head), 10, 0, $sql_count);
  }

  $symbol = variable_get('payment_symbol', '$');

  while ($coupon = db_fetch_object($result)) {
    if ($method == 'csv') {
      printf("\"%s\",\"%s\",%d\n\r", _coupon_format_coupon($coupon->coupon),
        ($coupon->operator == '%' ? "{$coupon->operand}% discount" :
        "{$coupon->operator}". format_currency($coupon->operand) ." discount"),
        $coupon->created);
    }
    else {
      $rows[] = array(
        array('data' => _coupon_format_coupon($coupon->coupon)),
        array('data' => ($coupon->operator == '%' ? "{$coupon->operand}% discount" :
          "{$coupon->operator}". format_currency($coupon->operand) ." discount")),
        array('data' => format_currency($coupon->coupon_discount), 'align' => 'right'),
        array('data' => $coupon->operator != '%' ?
          format_currency(($coupon->operand * ($coupon->operator == '+' ? 1 :
          -1)) - $coupon->coupon_discount) : '', 'align' => 'right'),
        array('data' => format_date($coupon->created, 'small')),
        array('data' => user_access(EC_PERM_MANAGE) ?
          l($coupon->created_txnid, "store/transaction/view/{$coupon->created_txnid}") :
          $coupon->created_txnid),
        array('data' => empty($method) and empty($coupon->created_txnid) ?
          l(t('Delete'), 'admin/store/coupon/delete/'. $coupon->coupon) : ''),
      );
    }
  }
  if ($method == 'csv') {
    exit();
  }
  if ($method == 'print') {
    foreach ($head as $key => $value) {
      unset($head[$key]['field']);
      unset($head[$key]['sort']);
    }
  }

  $output = theme('table', $head, $rows);
  if ($method == 'print') {
    echo $output;
    exit();
  }
  $output .= theme('pager', null, 10);
  return $output;
}

/**
 * Gift Certificate form
 *
 * @ingroup form
 */
function _coupon_gc_form($node = null) {
  $items = cart_current();
  $form['gc'] = array(
    '#type'           => 'fieldset',
    '#title'          => t('Options'),
  );
  $form['gc']['gc_price'] = array(
    '#type'           => 'price',
    '#title'          => t('Amount'),
    '#default_value'  => number_format($items[$node->nid]->gc_price, 2),
    '#size'           => 10,
    '#maxlength'      => 10,
    '#description'    => t('How much would you like the Gift Certificate to be?'),
    '#required'       => true,
  );
  $form['nid'] = array(
    '#type'           => 'value',
    '#value'          => $node->nid,
  );
  $form[] = array(
    '#type'           => 'submit',
    '#value'          => t('add to cart'),
  );
  return $form;
}

/**
 * Gift Certificate form
 */
function _coupon_gc_form_submit($form_id, $form_values) {
  if ($message = cart_update_item($form_values['nid'], null, array('gc_price' => $form_values['gc_price']))) {
    drupal_set_message($message);
  }
}
