<?php

/**
 * @file
 * These are hooks which are called by the ec_customer module.
 */

/**
 * @ingroup hooks
 * @{
 */

/**
 * @defgroup "e-Commerce Customer Types" "e-Commerce Customer Types"
 * @{
 * The Drupal e-Commerce Customer Types
 *
 * Welcome to the Drupal developers documentation for Drupal e-Commerce 
 * Customer Types. e-Commerce allows other modules to take control of customers
 * and e-Commerce will defer to external modules' way of handling the customer.
 */

/**
 * General description.
 *
 * @return
 *  An array of settings that define the customer type. The key of the array is:
 *   Customer type, something like 'user', 'anonymous'. Some like 'user' are special
 *      'user' refers to a local user in your installation - you can then avoid
 *      additional customer hooks because they're already provided.
 *  The inner array has:
 *   'name' = human readable
 *   'module' = the implementing module
 *   'settings_path' = a Drupal internal path to settings.
 *   'weight' = default weight, can be configured later anyway.
 *   'store_addresses' = true if the customer type manages storing addresses.
 *   'add_address' = true if the customer type can handle adding additional addresses
 *
 * Warning: at the moment if you don't specify 'store_addresses', some parts of ecommerce
 * will make it 'true' by default (see third arg of ec_customer_get_attr() and the
 * frequent calls which set the third arg to true.) This means that the attributes which are
 * marked 'optional' below are not actually optional -- you should really set all these
 * attributes for the time being.
 */
function hook_customer_info() {
  return array('user' =>
    array(
      // Required
      'name' => t('Address module customers'),
      'description' => t('Attach addresses to Drupal users which can be used for transactions'),
      'module' => 'address',
      'settings_path' => 'admin/ecsettings/ctype/address', // Can be omitted.
      // The following can be omitted and the values indicate the defaults if omitted.
      'weight' => 0,
      'store_addresses' => false,
      'add_address' => false,
    );
  );
}

/**
 * Return a customer which your Customer Type module handles. This may be a customer
 * which e-Commerce has never seen before so you're looking in your external location.
 * 
 * Note: Modules which are ctype 'user' do not need to answer this hook - a workable default
 * is provided by ec_customer_user.inc
 *
 * @param $info
 *  An array of data that resembles a customer object. It may contain and 'exid' which
 *  is the 'external id' of the customer - hence you'd look this up.
 *
 * @return
 *  An array keyed on 'type' (ie your customer type) and 'exid' (your external id) if it's
 *  known.
 */
function hook_customer_get_id($info) {
  // Perhaps do something if you don't know the current user.
  if (mymodule_user_unknown($info)) {
    $_SESSION['mymodule'] = db_next_id('{ec_customer}_mymodule');
  }
  // Return data to ec_customer.
  if (isset($_SESSION['mymodule'])) {
    return array(
      'type' => 'anonymous',
      'exid' => $_SESSION['mymodule'],
    );
  }
  // Other return a dumb default.
  return array(
    'type' => 'anonymous',
  );  
}

/**
 * General description.
 *
 * @param $abc
 *  ...
 *
 * @return
 *  ...
 */
function hook_xyz() {
}

